@@ -18,10 +18,11 @@
 
 #include "project.h"
 #include "config.h"
-#include <malloc.h>
+#include <stdlib.h>
 #include <lash/lash.h>
 #include <assert.h>
 #include <unistd.h>
+#include <string.h>
 
 /* Button callbacks */
 
