@@ -23,6 +23,7 @@
 #include <lash/lash.h>
 #include <lash/args.h>
 #include <lash/internal.h>
+#include <lash/internal_headers.h>
 
 void
 lash_args_free_argv(lash_args_t * args)
@@ -82,7 +83,7 @@ lash_args_duplicate(const lash_args_t *const src)
 	result->argc = 0;
 	result->argv = NULL;
 	if (src->argc > 0 && src->argv)
-		lash_args_set_args(result, src->argc, src->argv);
+		lash_args_set_args(result, src->argc, (const char**)src->argv);
 
 	return result;
 }
@@ -150,7 +151,7 @@ lash_args_get_flags(const lash_args_t * args)
 }
 
 void
-lash_args_set_args(lash_args_t * args, int argc, const char *const * argv)
+lash_args_set_args(lash_args_t * args, int argc, const char ** argv)
 {
 	int i;
 
